==> estateplat-common-1.2.4-20200910.042359-432-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxYhDyaq.java <==
package cn.gtmap.estateplat.model.exchange.share;
/*
 * @author <a href="mailto:yinyao@gtmap.cn">yinyao</a>
 * @version 1.0, 2017/5/26
 * @description 银行抵押信息
 */

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

@Table(name = "gx_yh_dyaq")
public class GxYhDyaq implements Serializable{
    @Id
    private String qlid;//权利id
    private String dyfs;//抵押方式
    private String zjgczl;//在建工程坐落
    private String zjgcdyfw;//在建工程抵押范围
    private Double bdbzzqse;//被担保主债权数额（最高债权数额）
    private Date zwlxksqx;//债务履行开始期限
    private Date zwlxjsqx;//债务履行结束期限
    private String zgzqqdss;//最高债权确定事实
    private Double zgzqqdse;//最高债权确定数额
    private String zxdyywh;//注销抵押业务号
    private String zxdyyy;//注销抵押业务号
    private Date zxsj;//注销时间
    private String fj;//附记
    private String dbfw;//担保范围
    private String dkfs;//贷款方式
    private Double fwpgjg;//房屋评估价格
    private Double tdpgjg;//土地评估价格
    private Double fwdyjg;//房屋抵押价格
    private Double tddyjg;//土地抵押价格
    private Double tddymj;//土地抵押面积
    private Double fwdymj;//房屋抵押面积
    private String ywid;//业务信息id
    private String lrzh;//录入证号
    private String bz;//备注
    private Double bdcjz;//不动产价值
    private String fczh;//房产证号
    private String tdzh;//土地证号
    private Integer dysw;//抵押顺位
    private String bdcdyh;//不动产单元号
    private String zl;//坐落
    private String fwytdm;//房屋用途代码
    private String fwytmc;//房屋用途名称
    private Double fwmj;//房屋面积
    private Double tdmj;//土地面积
    private String tdytdm;//土地用途代码
    private String tdytmc;//土地用途名称
    private String dyhtbh;//抵押合同编号
    private String dybgnr;//抵押变更内容
    private String zwr;//债务人
    private String mmhth;//买卖合同号
    private Date tdsyqssj;//土地使用起始时间
    private Date tdsyjssj;//土地使用结束时间
    private Date dyhtqdrq;//抵押合同签订时间
    private Double dyhtzqse;//抵押合同债权数额
    private Double dyjz;//抵押合同债权数额
    private String djyy;//登记原因
    private String djzx;//登记子项
    private String lrzhqlid;//录入证号qlid

    public String getDjyy() {
        return djyy;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public String getDjzx() {
        return djzx;
    }

    public void setDjzx(String djzx) {
        this.djzx = djzx;
    }

    /**
     * @author <a href="mailto:guting@gtmap.cn">guting</a>
     * @version 1.0,
     * @description 权属状态
     */
    private Integer qszt;
    /**
     * @author <a href="mailto:guting@gtmap.cn">guting</a>
     * @version 1.0,
     * @description 登记证明号
     */
    private String bdcdjzmh;

    /**
     * @author <a href="mailto:guting@gtmap.cn">guting</a>
     * @version 1.0,
     * @description 更正原因
     */
    private String gzyy;

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getDyfs() {
        return dyfs;
    }

    public void setDyfs(String dyfs) {
        this.dyfs = dyfs;
    }

    public String getZjgczl() {
        return zjgczl;
    }

    public void setZjgczl(String zjgczl) {
        this.zjgczl = zjgczl;
    }

    public String getZjgcdyfw() {
        return zjgcdyfw;
    }

    public void setZjgcdyfw(String zjgcdyfw) {
        this.zjgcdyfw = zjgcdyfw;
    }

    public Double getBdbzzqse() {
        return bdbzzqse;
    }

    public void setBdbzzqse(Double bdbzzqse) {
        this.bdbzzqse = bdbzzqse;
    }

    public Date getZwlxksqx() {
        return zwlxksqx;
    }

    public void setZwlxksqx(Date zwlxksqx) {
        this.zwlxksqx = zwlxksqx;
    }

    public Date getZwlxjsqx() {
        return zwlxjsqx;
    }

    public void setZwlxjsqx(Date zwlxjsqx) {
        this.zwlxjsqx = zwlxjsqx;
    }

    public String getZgzqqdss() {
        return zgzqqdss;
    }

    public void setZgzqqdss(String zgzqqdss) {
        this.zgzqqdss = zgzqqdss;
    }

    public Double getZgzqqdse() {
        return zgzqqdse;
    }

    public void setZgzqqdse(Double zgzqqdse) {
        this.zgzqqdse = zgzqqdse;
    }

    public String getZxdyywh() {
        return zxdyywh;
    }

    public void setZxdyywh(String zxdyywh) {
        this.zxdyywh = zxdyywh;
    }

    public String getZxdyyy() {
        return zxdyyy;
    }

    public void setZxdyyy(String zxdyyy) {
        this.zxdyyy = zxdyyy;
    }

    public Date getZxsj() {
        return zxsj;
    }

    public void setZxsj(Date zxsj) {
        this.zxsj = zxsj;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getDbfw() {
        return dbfw;
    }

    public void setDbfw(String dbfw) {
        this.dbfw = dbfw;
    }

    public String getDkfs() {
        return dkfs;
    }

    public void setDkfs(String dkfs) {
        this.dkfs = dkfs;
    }

    public Double getFwpgjg() {
        return fwpgjg;
    }

    public void setFwpgjg(Double fwpgjg) {
        this.fwpgjg = fwpgjg;
    }

    public Double getTdpgjg() {
        return tdpgjg;
    }

    public void setTdpgjg(Double tdpgjg) {
        this.tdpgjg = tdpgjg;
    }

    public Double getFwdyjg() {
        return fwdyjg;
    }

    public void setFwdyjg(Double fwdyjg) {
        this.fwdyjg = fwdyjg;
    }

    public Double getTddyjg() {
        return tddyjg;
    }

    public void setTddyjg(Double tddyjg) {
        this.tddyjg = tddyjg;
    }

    public Double getTddymj() {
        return tddymj;
    }

    public void setTddymj(Double tddymj) {
        this.tddymj = tddymj;
    }

    public Double getFwdymj() {
        return fwdymj;
    }

    public void setFwdymj(Double fwdymj) {
        this.fwdymj = fwdymj;
    }

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }

    public String getLrzh() {
        return lrzh;
    }

    public void setLrzh(String lrzh) {
        this.lrzh = lrzh;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public Double getBdcjz() {
        return bdcjz;
    }

    public void setBdcjz(Double bdcjz) {
        this.bdcjz = bdcjz;
    }

    public String getFczh() {
        return fczh;
    }

    public void setFczh(String fczh) {
        this.fczh = fczh;
    }

    public String getTdzh() {
        return tdzh;
    }

    public void setTdzh(String tdzh) {
        this.tdzh = tdzh;
    }

    public Integer getDysw() {
        return dysw;
    }

    public void setDysw(Integer dysw) {
        this.dysw = dysw;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getFwytdm() {
        return fwytdm;
    }

    public void setFwytdm(String fwytdm) {
        this.fwytdm = fwytdm;
    }

    public String getFwytmc() {
        return fwytmc;
    }

    public void setFwytmc(String fwytmc) {
        this.fwytmc = fwytmc;
    }

    public Double getFwmj() {
        return fwmj;
    }

    public void setFwmj(Double fwmj) {
        this.fwmj = fwmj;
    }

    public Double getTdmj() {
        return tdmj;
    }

    public void setTdmj(Double tdmj) {
        this.tdmj = tdmj;
    }

    public String getTdytdm() {
        return tdytdm;
    }

    public void setTdytdm(String tdytdm) {
        this.tdytdm = tdytdm;
    }

    public String getTdytmc() {
        return tdytmc;
    }

    public void setTdytmc(String tdytmc) {
        this.tdytmc = tdytmc;
    }

    public String getDyhtbh() {
        return dyhtbh;
    }

    public void setDyhtbh(String dyhtbh) {
        this.dyhtbh = dyhtbh;
    }

    public String getDybgnr() {
        return dybgnr;
    }

    public void setDybgnr(String dybgnr) {
        this.dybgnr = dybgnr;
    }

    public String getZwr() {
        return zwr;
    }

    public void setZwr(String zwr) {
        this.zwr = zwr;
    }

    public String getMmhth() {
        return mmhth;
    }

    public void setMmhth(String mmhth) {
        this.mmhth = mmhth;
    }

    public Date getTdsyqssj() {
        return tdsyqssj;
    }

    public void setTdsyqssj(Date tdsyqssj) {
        this.tdsyqssj = tdsyqssj;
    }

    public Date getTdsyjssj() {
        return tdsyjssj;
    }

    public void setTdsyjssj(Date tdsyjssj) {
        this.tdsyjssj = tdsyjssj;
    }

    public Date getDyhtqdrq() {
        return dyhtqdrq;
    }

    public void setDyhtqdrq(Date dyhtqdrq) {
        this.dyhtqdrq = dyhtqdrq;
    }

    public Double getDyhtzqse() {
        return dyhtzqse;
    }

    public void setDyhtzqse(Double dyhtzqse) {
        this.dyhtzqse = dyhtzqse;
    }

    public Double getDyjz() {
        return dyjz;
    }

    public void setDyjz(Double dyjz) {
        this.dyjz = dyjz;
    }

    public Integer getQszt() {
        return qszt;
    }

    public void setQszt(Integer qszt) {
        this.qszt = qszt;
    }

    public String getBdcdjzmh() {
        return bdcdjzmh;
    }

    public void setBdcdjzmh(String bdcdjzmh) {
        this.bdcdjzmh = bdcdjzmh;
    }

    public String getGzyy() {
        return gzyy;
    }

    public void setGzyy(String gzyy) {
        this.gzyy = gzyy;
    }

    public String getLrzhqlid() {
        return lrzhqlid;
    }

    public void setLrzhqlid(String lrzhqlid) {
        this.lrzhqlid = lrzhqlid;
    }
}

==> estateplat-common-1.2.4-20201126.082418-552-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxYhDyaq.java <==
package cn.gtmap.estateplat.model.exchange.share;
/*
 * @author <a href="mailto:yinyao@gtmap.cn">yinyao</a>
 * @version 1.0, 2017/5/26
 * @description 银行抵押信息
 */

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

@Table(name = "gx_yh_dyaq")
public class GxYhDyaq implements Serializable{
    @Id
    private String qlid;//权利id
    private String dyfs;//抵押方式
    private String zjgczl;//在建工程坐落
    private String zjgcdyfw;//在建工程抵押范围
    private Double bdbzzqse;//被担保主债权数额（最高债权数额）
    private Date zwlxksqx;//债务履行开始期限
    private Date zwlxjsqx;//债务履行结束期限
    private String zgzqqdss;//最高债权确定事实
    private Double zgzqqdse;//最高债权确定数额
    private String zxdyywh;//注销抵押业务号
    private String zxdyyy;//注销抵押业务号
    private Date zxsj;//注销时间
    private String fj;//附记
    private String dbfw;//担保范围
    private String dkfs;//贷款方式
    private Double fwpgjg;//房屋评估价格
    private Double tdpgjg;//土地评估价格
    private Double fwdyjg;//房屋抵押价格
    private Double tddyjg;//土地抵押价格
    private Double tddymj;//土地抵押面积
    private Double fwdymj;//房屋抵押面积
    private String ywid;//业务信息id
    private String lrzh;//录入证号
    private String bz;//备注
    private Double bdcjz;//不动产价值
    private String fczh;//房产证号
    private String tdzh;//土地证号
    private Integer dysw;//抵押顺位
    private String bdcdyh;//不动产单元号
    private String zl;//坐落
    private String fwytdm;//房屋用途代码
    private String fwytmc;//房屋用途名称
    private Double fwmj;//房屋面积
    private Double tdmj;//土地面积
    private String tdytdm;//土地用途代码
    private String tdytmc;//土地用途名称
    private String dyhtbh;//抵押合同编号
    private String dybgnr;//抵押变更内容
    private String zwr;//债务人
    private String mmhth;//买卖合同号
    private Date tdsyqssj;//土地使用起始时间
    private Date tdsyjssj;//土地使用结束时间
    private Date dyhtqdrq;//抵押合同签订时间
    private Double dyhtzqse;//抵押合同债权数额
    private Double dyjz;//抵押合同债权数额
    private String djyy;//登记原因
    private String djzx;//登记子项
    private String lrzhqlid;//录入证号qlid
    private String sfhcdzzz;//是否合成电子证照

    public String getDjyy() {
        return djyy;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public String getDjzx() {
        return djzx;
    }

    public void setDjzx(String djzx) {
        this.djzx = djzx;
    }

    /**
     * @author <a href="mailto:guting@gtmap.cn">guting</a>
     * @version 1.0,
     * @description 权属状态
     */
    private Integer qszt;
    /**
     * @author <a href="mailto:guting@gtmap.cn">guting</a>
     * @version 1.0,
     * @description 登记证明号
     */
    private String bdcdjzmh;

    /**
     * @author <a href="mailto:guting@gtmap.cn">guting</a>
     * @version 1.0,
     * @description 更正原因
     */
    private String gzyy;

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getDyfs() {
        return dyfs;
    }

    public void setDyfs(String dyfs) {
        this.dyfs = dyfs;
    }

    public String getZjgczl() {
        return zjgczl;
    }

    public void setZjgczl(String zjgczl) {
        this.zjgczl = zjgczl;
    }

    public String getZjgcdyfw() {
        return zjgcdyfw;
    }

    public void setZjgcdyfw(String zjgcdyfw) {
        this.zjgcdyfw = zjgcdyfw;
    }

    public Double getBdbzzqse() {
        return bdbzzqse;
    }

    public void setBdbzzqse(Double bdbzzqse) {
        this.bdbzzqse = bdbzzqse;
    }

    public Date getZwlxksqx() {
        return zwlxksqx;
    }

    public void setZwlxksqx(Date zwlxksqx) {
        this.zwlxksqx = zwlxksqx;
    }

    public Date getZwlxjsqx() {
        return zwlxjsqx;
    }

    public void setZwlxjsqx(Date zwlxjsqx) {
        this.zwlxjsqx = zwlxjsqx;
    }

    public String getZgzqqdss() {
        return zgzqqdss;
    }

    public void setZgzqqdss(String zgzqqdss) {
        this.zgzqqdss = zgzqqdss;
    }

    public Double getZgzqqdse() {
        return zgzqqdse;
    }

    public void setZgzqqdse(Double zgzqqdse) {
        this.zgzqqdse = zgzqqdse;
    }

    public String getZxdyywh() {
        return zxdyywh;
    }

    public void setZxdyywh(String zxdyywh) {
        this.zxdyywh = zxdyywh;
    }

    public String getZxdyyy() {
        return zxdyyy;
    }

    public void setZxdyyy(String zxdyyy) {
        this.zxdyyy = zxdyyy;
    }

    public Date getZxsj() {
        return zxsj;
    }

    public void setZxsj(Date zxsj) {
        this.zxsj = zxsj;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getDbfw() {
        return dbfw;
    }

    public void setDbfw(String dbfw) {
        this.dbfw = dbfw;
    }

    public String getDkfs() {
        return dkfs;
    }

    public void setDkfs(String dkfs) {
        this.dkfs = dkfs;
    }

    public Double getFwpgjg() {
        return fwpgjg;
    }

    public void setFwpgjg(Double fwpgjg) {
        this.fwpgjg = fwpgjg;
    }

    public Double getTdpgjg() {
        return tdpgjg;
    }

    public void setTdpgjg(Double tdpgjg) {
        this.tdpgjg = tdpgjg;
    }

    public Double getFwdyjg() {
        return fwdyjg;
    }

    public void setFwdyjg(Double fwdyjg) {
        this.fwdyjg = fwdyjg;
    }

    public Double getTddyjg() {
        return tddyjg;
    }

    public void setTddyjg(Double tddyjg) {
        this.tddyjg = tddyjg;
    }

    public Double getTddymj() {
        return tddymj;
    }

    public void setTddymj(Double tddymj) {
        this.tddymj = tddymj;
    }

    public Double getFwdymj() {
        return fwdymj;
    }

    public void setFwdymj(Double fwdymj) {
        this.fwdymj = fwdymj;
    }

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }

    public String getLrzh() {
        return lrzh;
    }

    public void setLrzh(String lrzh) {
        this.lrzh = lrzh;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public Double getBdcjz() {
        return bdcjz;
    }

    public void setBdcjz(Double bdcjz) {
        this.bdcjz = bdcjz;
    }

    public String getFczh() {
        return fczh;
    }

    public void setFczh(String fczh) {
        this.fczh = fczh;
    }

    public String getTdzh() {
        return tdzh;
    }

    public void setTdzh(String tdzh) {
        this.tdzh = tdzh;
    }

    public Integer getDysw() {
        return dysw;
    }

    public void setDysw(Integer dysw) {
        this.dysw = dysw;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getFwytdm() {
        return fwytdm;
    }

    public void setFwytdm(String fwytdm) {
        this.fwytdm = fwytdm;
    }

    public String getFwytmc() {
        return fwytmc;
    }

    public void setFwytmc(String fwytmc) {
        this.fwytmc = fwytmc;
    }

    public Double getFwmj() {
        return fwmj;
    }

    public void setFwmj(Double fwmj) {
        this.fwmj = fwmj;
    }

    public Double getTdmj() {
        return tdmj;
    }

    public void setTdmj(Double tdmj) {
        this.tdmj = tdmj;
    }

    public String getTdytdm() {
        return tdytdm;
    }

    public void setTdytdm(String tdytdm) {
        this.tdytdm = tdytdm;
    }

    public String getTdytmc() {
        return tdytmc;
    }

    public void setTdytmc(String tdytmc) {
        this.tdytmc = tdytmc;
    }

    public String getDyhtbh() {
        return dyhtbh;
    }

    public void setDyhtbh(String dyhtbh) {
        this.dyhtbh = dyhtbh;
    }

    public String getDybgnr() {
        return dybgnr;
    }

    public void setDybgnr(String dybgnr) {
        this.dybgnr = dybgnr;
    }

    public String getZwr() {
        return zwr;
    }

    public void setZwr(String zwr) {
        this.zwr = zwr;
    }

    public String getMmhth() {
        return mmhth;
    }

    public void setMmhth(String mmhth) {
        this.mmhth = mmhth;
    }

    public Date getTdsyqssj() {
        return tdsyqssj;
    }

    public void setTdsyqssj(Date tdsyqssj) {
        this.tdsyqssj = tdsyqssj;
    }

    public Date getTdsyjssj() {
        return tdsyjssj;
    }

    public void setTdsyjssj(Date tdsyjssj) {
        this.tdsyjssj = tdsyjssj;
    }

    public Date getDyhtqdrq() {
        return dyhtqdrq;
    }

    public void setDyhtqdrq(Date dyhtqdrq) {
        this.dyhtqdrq = dyhtqdrq;
    }

    public Double getDyhtzqse() {
        return dyhtzqse;
    }

    public void setDyhtzqse(Double dyhtzqse) {
        this.dyhtzqse = dyhtzqse;
    }

    public Double getDyjz() {
        return dyjz;
    }

    public void setDyjz(Double dyjz) {
        this.dyjz = dyjz;
    }

    public Integer getQszt() {
        return qszt;
    }

    public void setQszt(Integer qszt) {
        this.qszt = qszt;
    }

    public String getBdcdjzmh() {
        return bdcdjzmh;
    }

    public void setBdcdjzmh(String bdcdjzmh) {
        this.bdcdjzmh = bdcdjzmh;
    }

    public String getGzyy() {
        return gzyy;
    }

    public void setGzyy(String gzyy) {
        this.gzyy = gzyy;
    }

    public String getLrzhqlid() {
        return lrzhqlid;
    }

    public void setLrzhqlid(String lrzhqlid) {
        this.lrzhqlid = lrzhqlid;
    }

    public String getSfhcdzzz() {
        return sfhcdzzz;
    }

    public void setSfhcdzzz(String sfhcdzzz) {
        this.sfhcdzzz = sfhcdzzz;
    }
}
